@@ -368,7 +368,7 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll,
 		g_ptr_array_add (array, g_strdup_printf ("-t%i", target_whitepoint));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", display));
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI) {
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI_PHOTO) {
 		g_ptr_array_add (array, g_strdup ("-H"));
 	}
 	g_ptr_array_add (array, g_strdup ("-P 0.5,0.5,0.8"));
@@ -572,7 +572,7 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
 	g_ptr_array_add (array, g_strdup ("-k"));
 	g_ptr_array_add (array, g_strdup_printf ("%s.cal", basename));
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI) {
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI_PHOTO) {
 		g_ptr_array_add (array, g_strdup ("-H"));
 		g_ptr_array_add (array, g_strdup ("-N"));
 	}
@@ -1350,7 +1350,7 @@ gcm_calibrate_argyll_get_sensor_target (GcmCalibrateArgyll *calibrate_argyll)
 		return "SS";
 	if (sensor_kind == CD_SENSOR_KIND_I1_PRO)
 		return "i1";
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI_PHOTO)
 		return "CM";
 	return NULL;
 }
@@ -1409,7 +1409,7 @@ gcm_calibrate_argyll_printer_generate_targets (GcmCalibrateArgyll *calibrate_arg
 
 #ifdef USE_DOUBLE_DENSITY
 	/* use double density */
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI ||
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI_PHOTO ||
 	    sensor_kind == CD_SENSOR_KIND_SPECTRO_SCAN) {
 		g_ptr_array_add (array, g_strdup ("-h"));
 	}
@@ -2554,7 +2554,7 @@ gcm_calibrate_argyll_status_changed_cb (GcmPrint *print,
 	case GTK_PRINT_STATUS_PRINTING:
 		/* TRANSLATORS: dialog message */
 		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-					   _("Printing the targets..."),
+					   _("Printing the targets…"),
 					   GCM_CALIBRATE_UI_STATUS);
 		break;
 	case GTK_PRINT_STATUS_FINISHED:
