@@ -770,6 +770,7 @@ gcm_calib_setup_page_intro (GcmCalibratePriv *priv)
 static gboolean
 gcm_calibrate_is_livecd (void)
 {
+#ifdef __linux__
 	gboolean ret;
 	gchar *data = NULL;
 	GError *error = NULL;
@@ -787,6 +788,9 @@ gcm_calibrate_is_livecd (void)
 out:
 	g_free (data);
 	return ret;
+#else
+	return FALSE;
+#endif
 }
 
 /**
