@@ -598,7 +598,7 @@ gcm_profile_get_precooked_md5 (cmsHPROFILE lcms_profile)
 
 	/* check to see if we have a pre-cooked MD5 */
 	cmsGetHeaderProfileID (lcms_profile, profile_id);
-	for (i=0; i<16; i++) {
+	for (i = 0; i < 16; i++) {
 		if (profile_id[i] != 0) {
 			md5_precooked = TRUE;
 			break;
@@ -609,7 +609,7 @@ gcm_profile_get_precooked_md5 (cmsHPROFILE lcms_profile)
 
 	/* convert to a hex string */
 	md5 = g_new0 (gchar, 32 + 1);
-	for (i=0; i<16; i++)
+	for (i = 0; i < 16; i++)
 		g_snprintf (md5 + i*2, 3, "%02x", profile_id[i]);
 out:
 	return md5;
@@ -657,7 +657,7 @@ gcm_profile_calc_whitepoint (GcmProfile *profile)
 	cmsDoTransform (transform, data, &whitepoint, 1);
 
 	/* convert to lcms xyY values */
-	cd_color_set_xyz (priv->white,
+	cd_color_xyz_set (priv->white,
 			  whitepoint.X, whitepoint.Y, whitepoint.Z);
 	cmsXYZ2xyY (&tmp, &whitepoint);
 	g_debug ("whitepoint = %f,%f [%f]", tmp.x, tmp.y, tmp.Y);
@@ -733,7 +733,7 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 	/* get white point */
 	ret = gcm_profile_calc_whitepoint (profile);
 	if (!ret)
-		cd_color_clear_xyz (priv->white);
+		cd_color_xyz_clear (priv->white);
 
 	/* get the profile kind */
 	profile_class = cmsGetDeviceClass (priv->lcms_profile);
@@ -807,11 +807,11 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 		cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigRedMatrixColumnTag);
 		if (cie_xyz != NULL) {
 			/* assume that if red is present, the green and blue are too */
-			cd_color_copy_xyz ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Red);
+			cd_color_xyz_copy ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Red);
 			cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigGreenMatrixColumnTag);
-			cd_color_copy_xyz ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Green);
+			cd_color_xyz_copy ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Green);
 			cie_xyz = cmsReadTag (priv->lcms_profile, cmsSigBlueMatrixColumnTag);
-			cd_color_copy_xyz ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Blue);
+			cd_color_xyz_copy ((CdColorXYZ *) cie_xyz, (CdColorXYZ *) &cie_illum.Blue);
 			got_illuminants = TRUE;
 		} else {
 			g_debug ("failed to get illuminants");
@@ -858,17 +858,17 @@ gcm_profile_parse_data (GcmProfile *profile, const guint8 *data, gsize length, G
 
 	/* we've got valid values */
 	if (got_illuminants) {
-		cd_color_set_xyz (priv->red,
+		cd_color_xyz_set (priv->red,
 				   cie_illum.Red.X, cie_illum.Red.Y, cie_illum.Red.Z);
-		cd_color_set_xyz (priv->green,
+		cd_color_xyz_set (priv->green,
 				   cie_illum.Green.X, cie_illum.Green.Y, cie_illum.Green.Z);
-		cd_color_set_xyz (priv->blue,
+		cd_color_xyz_set (priv->blue,
 				   cie_illum.Blue.X, cie_illum.Blue.Y, cie_illum.Blue.Z);
 	} else {
 		g_debug ("failed to get luminance values");
-		cd_color_clear_xyz (priv->red);
-		cd_color_clear_xyz (priv->green);
-		cd_color_clear_xyz (priv->blue);
+		cd_color_xyz_clear (priv->red);
+		cd_color_xyz_clear (priv->green);
+		cd_color_xyz_clear (priv->blue);
 	}
 
 	/* get the profile created time and date */
@@ -1009,7 +1009,7 @@ gcm_profile_set_whitepoint (GcmProfile *profile, const CdColorXYZ *whitepoint, G
 		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
 
 	/* copy */
-	cd_color_copy_xyz (whitepoint, priv->white);
+	cd_color_xyz_copy (whitepoint, priv->white);
 
 	/* write tag */
 	ret = cmsWriteTag (priv->lcms_profile, cmsSigMediaWhitePointTag, priv->white);
@@ -1048,9 +1048,9 @@ gcm_profile_set_primaries (GcmProfile *profile,
 		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
 
 	/* copy */
-	cd_color_copy_xyz (red, priv->red);
-	cd_color_copy_xyz (green, priv->green);
-	cd_color_copy_xyz (blue, priv->blue);
+	cd_color_xyz_copy (red, priv->red);
+	cd_color_xyz_copy (green, priv->green);
+	cd_color_xyz_copy (blue, priv->blue);
 
 	/* write tags */
 	ret = cmsWriteTag (priv->lcms_profile, cmsSigRedMatrixColumnTag, priv->red);
@@ -1305,7 +1305,7 @@ gcm_profile_guess_and_add_vcgt (GcmProfile *profile, GError **error)
 
 	/* populate with data */
 	divamount = 1.0f / (gfloat) (size - 1);
-	for (i=0; i<size; i++) {
+	for (i = 0; i < size; i++) {
 		divadd = divamount * (gfloat) i;
 
 		/* grey component */
@@ -1328,14 +1328,14 @@ gcm_profile_guess_and_add_vcgt (GcmProfile *profile, GError **error)
 	cmsDoTransform (transform, values_in, values_out, size);
 
 	/* unroll the data */
-	for (i=0; i<size; i++) {
+	for (i = 0; i < size; i++) {
 		rawdata[0][i] = values_out[(i * 3)+0] * 0xffff;
 		rawdata[1][i] = values_out[(i * 3)+1] * 0xffff;
 		rawdata[2][i] = values_out[(i * 3)+2] * 0xffff;
 	}
 
 	/* build tone curves */
-	for (i=0; i<3; i++)
+	for (i = 0; i < 3; i++)
 		transfer_curve[i] = cmsBuildTabulatedToneCurve16 (NULL, 256, rawdata[i]);
 
 	/* write to VCGT */
@@ -1384,7 +1384,7 @@ gcm_profile_generate_vcgt (GcmProfile *profile, guint size)
 
 	/* create array */
 	array = g_ptr_array_new_with_free_func (g_free);
-	for (i=0; i<size; i++) {
+	for (i = 0; i < size; i++) {
 		in = (gdouble) i / (gdouble) (size - 1);
 		tmp = g_new0 (GcmClutData, 1);
 		tmp->red = cmsEvalToneCurveFloat(vcgt[0], in) * (gdouble) 0xffff;
@@ -1427,7 +1427,7 @@ gcm_profile_set_vcgt_from_data (GcmProfile *profile, guint16 *red, guint16 *gree
 		priv->lcms_profile = cmsCreateProfilePlaceholder (NULL);
 
 	/* check monotonic */
-	for (i=0; i<size-1; i++) {
+	for (i = 0; i < size-1; i++) {
 		if (red[i] > red[i+1] ||
 		    green[i] > green[i+1] ||
 		    blue[i] > blue[i+1]) {
@@ -1442,12 +1442,12 @@ gcm_profile_set_vcgt_from_data (GcmProfile *profile, guint16 *red, guint16 *gree
 	vcgt_curve[2] = cmsBuildTabulatedToneCurve16 (NULL, size, blue);
 
 	/* smooth it */
-	for (i=0; i<3; i++)
+	for (i = 0; i < 3; i++)
 		cmsSmoothToneCurve (vcgt_curve[i], 5);
 
 	/* write the tag */
 	ret = cmsWriteTag (priv->lcms_profile, cmsSigVcgtType, vcgt_curve);
-	for (i=0; i<3; i++)
+	for (i = 0; i < 3; i++)
 		cmsFreeToneCurve (vcgt_curve[i]);
 	if (!ret) {
 		g_set_error_literal (error, 1, 0, "Failed to set vcgt");
@@ -1496,7 +1496,7 @@ gcm_profile_generate_curve (GcmProfile *profile, guint size)
 		/* create input array */
 		values_in = g_new0 (gdouble, size * 3 * component_width);
 		divamount = 1.0f / (gfloat) (size - 1);
-		for (i=0; i<size; i++) {
+		for (i = 0; i < size; i++) {
 			divadd = divamount * (gfloat) i;
 
 			/* red component */
@@ -1533,7 +1533,7 @@ gcm_profile_generate_curve (GcmProfile *profile, guint size)
 		/* create output array */
 		array = g_ptr_array_new_with_free_func (g_free);
 
-		for (i=0; i<size; i++) {
+		for (i = 0; i < size; i++) {
 			data = g_new0 (GcmClutData, 1);
 
 			/* default values */
@@ -2044,7 +2044,7 @@ gcm_profile_get_named_colors (GcmProfile *profile, GError **error)
 		goto out;
 	}
 	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	for (i=0; i<count; i++) {
+	for (i = 0; i < count; i++) {
 
 		/* parse title */
 		string = g_string_new ("");
@@ -2068,7 +2068,7 @@ gcm_profile_get_named_colors (GcmProfile *profile, GError **error)
 		ret = g_utf8_validate (string->str, string->len, NULL);
 		if (!ret) {
 			g_warning ("invalid 7 bit ASCII / UTF8, repairing");
-			for (j=0; j<string->len; j++) {
+			for (j = 0; j < string->len; j++) {
 				tmp = (guchar) string->str[j];
 
 				/* (R) */
@@ -2089,7 +2089,7 @@ gcm_profile_get_named_colors (GcmProfile *profile, GError **error)
 		ret = g_utf8_validate (string->str, string->len, NULL);
 		if (!ret) {
 			g_warning ("failed to fix: skipping entry");
-			for (j=0; j<string->len; j++)
+			for (j = 0; j < string->len; j++)
 				g_print ("'%c' (%x)\n", string->str[j], (gchar)string->str[j]);
 			continue;
 		}
@@ -2251,16 +2251,16 @@ gcm_profile_set_property (GObject *object, guint prop_id, const GValue *value, G
 		gcm_profile_set_size (profile, g_value_get_uint (value));
 		break;
 	case PROP_WHITE:
-		cd_color_copy_xyz (g_value_get_boxed (value), priv->white);
+		cd_color_xyz_copy (g_value_get_boxed (value), priv->white);
 		break;
 	case PROP_RED:
-		cd_color_copy_xyz (g_value_get_boxed (value), priv->red);
+		cd_color_xyz_copy (g_value_get_boxed (value), priv->red);
 		break;
 	case PROP_GREEN:
-		cd_color_copy_xyz (g_value_get_boxed (value), priv->green);
+		cd_color_xyz_copy (g_value_get_boxed (value), priv->green);
 		break;
 	case PROP_BLUE:
-		cd_color_copy_xyz (g_value_get_boxed (value), priv->blue);
+		cd_color_xyz_copy (g_value_get_boxed (value), priv->blue);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
